from sports.nba.nba_team import NBA_Team


class PortlandTrailBlazers(NBA_Team):
    """
    NBA's Portland TrailBlazers Static Information

    """
    full_name = "Portland TrailBlazers"
    name = "TrailBlazers"
    team_id = 1610612757

    def __init__(self):
        """
        """
        super().__init__()

