from sports.nba.nba_team import NBA_Team


class HoustonRockets(NBA_Team):
    """
    NBA Golden State Warriors Static Information

    """
    full_name = "Houston Rockets"
    name = "Rockets"
    team_id = 1610612745

    def __init__(self):
        """
        """
        super().__init__()
